pub struct CodeScanningAlertFixedAlert {Show 13 fields
pub created_at: DateTime<Utc>,
pub dismissed_at: Option<DateTime<Utc>>,
pub dismissed_by: Option<User>,
pub dismissed_reason: Option<CodeScanningAlertFixedAlertDismissedReason>,
pub html_url: String,
pub instances: Vec<AlertInstance>,
pub instances_url: Option<String>,
pub most_recent_instance: Option<AlertInstance>,
pub number: i64,
pub rule: CodeScanningAlertFixedAlertRule,
pub state: CodeScanningAlertFixedAlertState,
pub tool: CodeScanningAlertFixedAlertTool,
pub url: String,
}Expand description
The code scanning alert involved in the event.
Fields
created_at: DateTime<Utc>The time that the alert was created in ISO 8601 format:
YYYY-MM-DDTHH:MM:SSZ.
dismissed_at: Option<DateTime<Utc>>The time that the alert was dismissed in ISO 8601 format:
YYYY-MM-DDTHH:MM:SSZ.
dismissed_by: Option<User>dismissed_reason: Option<CodeScanningAlertFixedAlertDismissedReason>The reason for dismissing or closing the alert. Can be one of: false positive, won't fix, and used in tests.
html_url: StringThe GitHub URL of the alert resource.
instances: Vec<AlertInstance>instances_url: Option<String>most_recent_instance: Option<AlertInstance>number: i64The code scanning alert number.
rule: CodeScanningAlertFixedAlertRulestate: CodeScanningAlertFixedAlertStateState of a code scanning alert.
tool: CodeScanningAlertFixedAlertToolurl: StringThe REST API URL of the alert resource.