pub struct CodeScanningAlertReopenedAlert {
pub created_at: DateTime<Utc>,
pub dismissed_at: (),
pub dismissed_by: (),
pub dismissed_reason: (),
pub html_url: String,
pub instances: Vec<AlertInstance>,
pub most_recent_instance: Option<AlertInstance>,
pub number: i64,
pub rule: CodeScanningAlertReopenedAlertRule,
pub state: CodeScanningAlertReopenedAlertState,
pub tool: CodeScanningAlertReopenedAlertTool,
pub url: String,
}Expand description
The code scanning alert involved in the event.
Fields
created_at: DateTime<Utc>The time that the alert was created in ISO 8601 format:
YYYY-MM-DDTHH:MM:SSZ.
dismissed_at: ()The time that the alert was dismissed in ISO 8601 format:
YYYY-MM-DDTHH:MM:SSZ.
dismissed_by: ()dismissed_reason: ()The reason for dismissing or closing the alert. Can be one of: false positive, won't fix, and used in tests.
html_url: StringThe GitHub URL of the alert resource.
instances: Vec<AlertInstance>most_recent_instance: Option<AlertInstance>number: i64The code scanning alert number.
rule: CodeScanningAlertReopenedAlertRulestate: CodeScanningAlertReopenedAlertStateState of a code scanning alert.
tool: CodeScanningAlertReopenedAlertToolurl: StringThe REST API URL of the alert resource.